==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/RouteSpecHttpRouteMatchQueryParameterMatchArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.RouteSpecHttpRouteMatchQueryParameterMatchArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property exact The exact path to match on.
 */
public data class RouteSpecHttpRouteMatchQueryParameterMatchArgs(
    public val exact: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.RouteSpecHttpRouteMatchQueryParameterMatchArgs> {
    override fun toJava():
        com.pulumi.aws.appmesh.inputs.RouteSpecHttpRouteMatchQueryParameterMatchArgs =
        com.pulumi.aws.appmesh.inputs.RouteSpecHttpRouteMatchQueryParameterMatchArgs.builder()
            .exact(exact?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RouteSpecHttpRouteMatchQueryParameterMatchArgs].
 */
@PulumiTagMarker
public class RouteSpecHttpRouteMatchQueryParameterMatchArgsBuilder internal constructor() {
    private var exact: Output<String>? = null

    /**
     * @param value The exact path to match on.
     */
    @JvmName("pjxmcxdtodbfwele")
    public suspend fun exact(`value`: Output<String>) {
        this.exact = value
    }

    /**
     * @param value The exact path to match on.
     */
    @JvmName("sjpusvoscditvcbl")
    public suspend fun exact(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exact = mapped
    }

    internal fun build(): RouteSpecHttpRouteMatchQueryParameterMatchArgs =
        RouteSpecHttpRouteMatchQueryParameterMatchArgs(
            exact = exact,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/RouteSpecHttpRouteMatchQueryParameterMatchArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.RouteSpecHttpRouteMatchQueryParameterMatchArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property exact The exact query parameter to match on.
 */
public data class RouteSpecHttpRouteMatchQueryParameterMatchArgs(
    public val exact: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.RouteSpecHttpRouteMatchQueryParameterMatchArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.RouteSpecHttpRouteMatchQueryParameterMatchArgs =
        com.pulumi.aws.appmesh.inputs.RouteSpecHttpRouteMatchQueryParameterMatchArgs.builder()
            .exact(exact?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RouteSpecHttpRouteMatchQueryParameterMatchArgs].
 */
@PulumiTagMarker
public class RouteSpecHttpRouteMatchQueryParameterMatchArgsBuilder internal constructor() {
    private var exact: Output<String>? = null

    /**
     * @param value The exact query parameter to match on.
     */
    @JvmName("jflgkjljguaqsfto")
    public suspend fun exact(`value`: Output<String>) {
        this.exact = value
    }

    /**
     * @param value The exact query parameter to match on.
     */
    @JvmName("aigipmldonmejgmk")
    public suspend fun exact(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exact = mapped
    }

    internal fun build(): RouteSpecHttpRouteMatchQueryParameterMatchArgs =
        RouteSpecHttpRouteMatchQueryParameterMatchArgs(
            exact = exact,
        )
}
